.. rrda documentation master file, created by
   sphinx-quickstart on Wed Jun  4 16:14:34 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Sahuwai's documentation!
====================================

RRDA Rest DNS API client

Contents:

.. toctree::
   :maxdepth: 4

   installation
   usage
   api
   contribute
   showcase
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

